==> _private_core_network-1.2.25.tar.gz: lib/network_resources/platform/platform_repo.dart <==
import 'dart:collection';

import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';

import '../common/models/file_upload_result.dart';
import 'app_api.dart';
import 'models/platform_status_chat.dart';

class PlatformRepo {
  PlatformRepo._();

  static PlatformRepo? _instance;

  factory PlatformRepo([MyAppApi? api]) {
    _instance ??= PlatformRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Map<String, dynamic> _mapParms([Map? value]) {
    Map<String, dynamic> params = {};
    if (value != null && value.isNotEmpty) params.addAll(HashMap.from(value));
    params
      ..removeWhere((key, value) => value == null)
      ..addAll({
        'platformId': valuePlatformByConfig(),
        'languageCode': appPrefs.languageCode,
      });
    return params;
  }

  Future<List<PlatformStatusChat>> getStatusChatList(params) async {
    NetworkResponse response = await _api.getStatusChatList(_mapParms(params));
    return response.data ?? [];
  }

  Future<PlatformStatusChat?> getMyCurrentStatusChatForPlatformId(
      params) async {
    NetworkResponse response =
        await _api.getMyCurrentStatusChatForPlatformId(_mapParms(params));
    return response.data;
  }

  Future<PlatformStatusChat?> getStatusChatForPlatformIdByUsername(
      params) async {
    NetworkResponse response =
        await _api.getStatusChatForPlatformIdByUsername(_mapParms(params));
    return response.data;
  }

  Future<bool> updateStatusChatForPlatformId(params) async {
    NetworkResponse response =
        await _api.updateStatusChatForPlatformId(_mapParms(params));
    return response.data ?? false;
  }

  Future<bool> createChatGroup(params) async {
    NetworkResponse response = await _api.createChatGroup(_mapParms(params));
    return response.data ?? false;
  }

  Future<FileUploadResult?> setThumbnailForChatGroup(
      groupId, bytes, filePath) async {
    NetworkResponse response =
        await _api.setThumbnailForChatGroup(groupId, bytes, filePath);
    return response.data;
  }
}

==> _private_core_network-1.2.54.tar.gz: lib/network_resources/platform/platform_repo.dart <==
import 'dart:collection';

import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';

import '../common/models/file_upload_result.dart';
import 'app_api.dart';
import 'models/platform_status_chat.dart';

class PlatformRepo {
  PlatformRepo._();

  static PlatformRepo? _instance;

  factory PlatformRepo([MyAppApi? api]) {
    _instance ??= PlatformRepo._();
    _instance!._api = api ?? MyAppApiImp();
    return _instance!;
  }

  late MyAppApi _api;

  Map<String, dynamic> _mapParms([Map? value]) {
    Map<String, dynamic> params = {};
    if (value != null && value.isNotEmpty) params.addAll(HashMap.from(value));
    params
      ..removeWhere((key, value) => value == null)
      ..addAll({
        'platformId': valuePlatformByConfig(),
        'languageCode': appPrefs.languageCode,
      });
    return params;
  }

  Future<List<PlatformStatusChat>> getStatusChatList(params) async {
    NetworkResponse response = await _api.getStatusChatList(_mapParms(params));
    return response.data ?? [];
  }

  Future<PlatformStatusChat?> getMyCurrentStatusChatForPlatformId(
      params) async {
    NetworkResponse response =
        await _api.getMyCurrentStatusChatForPlatformId(_mapParms(params));
    return response.data;
  }

  Future<PlatformStatusChat?> getStatusChatForPlatformId(params) async {
    NetworkResponse response =
        await _api.getStatusChatForPlatformId(_mapParms(params));
    return response.data;
  }

  Future<bool> updateStatusChatForPlatformId(params) async {
    NetworkResponse response =
        await _api.updateStatusChatForPlatformId(_mapParms(params));
    return response.data ?? false;
  }

  Future<bool> createChatGroup(params) async {
    NetworkResponse response = await _api.createChatGroup(_mapParms(params));
    return response.data ?? false;
  }

  Future<FileUploadResult?> setThumbnailForChatGroup(
      groupId, bytes, filePath) async {
    NetworkResponse response =
        await _api.setThumbnailForChatGroup(groupId, bytes, filePath);
    return response.data;
  }
}
